@@ -7,6 +7,7 @@ in the format expected by the DUST solver.
 from dataclasses import dataclass, field
 from datetime import datetime, timezone
 from typing import Any, Optional, TextIO
+
 import numpy as np
 
 __all__ = [
@@ -27,21 +28,30 @@ __all__ = [
 class Point:
     """Mesh point with geometric and aerodynamic properties.
 
-    Attributes:
-        id: Unique point identifier (1-based index)
-        coordinates: Cartesian coordinates [x, y, z] in the component reference frame
-        chord: Local chord length
-        twist: Local twist angle (degrees)
-        airfoil: Airfoil section name (without .dat extension)
-        airfoil_table: Airfoil aerodynamic table name (without .c81 extension)
-        section_normal: Section normal definition (reference_line, y_axis, y_axis_neg, vector)
-        flip_section: Whether to flip the airfoil section vertically
+    Attributes
+    ----------
+    id : int
+        Unique point identifier (1-based index)
+    coordinates : list[float]
+        Cartesian coordinates [x, y, z] in the component reference frame
+    chord : float
+        Local chord length
+    twist : float
+        Local twist angle (degrees)
+    airfoil : str
+        Airfoil section name (without .dat extension)
+    airfoil_table : str
+        Airfoil aerodynamic table name (without .c81 extension)
+    section_normal : str, optional
+        Section normal definition (reference_line, y_axis, y_axis_neg, vector)
+    flip_section : bool, optional
+        Whether to flip the airfoil section vertically
     """
 
     id: int
+    coordinates: list[float]
     chord: float
     twist: float
-    coordinates: list[float] = field(default_factory=lambda: [0.0, 0.0, 0.0])
     airfoil: str = "interp"
     airfoil_table: Optional[str] = None
     section_normal: str = "reference_line"
@@ -82,18 +92,30 @@ class Point:
 class Line:
     """Line definition for pointwise mesh.
 
-    Attributes:
-        type: Line type ('spline' or 'straight')
-        end_points: List of two point IDs defining the line endpoints (1-based indices)
-        nelem_line: Number of elements along line
-        type_span: Spanwise discretization type: could be 'uniform', 'cosine', 'cosine_ib', 'cosine_ob', 'geoseries', 'geoseries_ob', 'geoseries_ib'
-        r_ob: Outer boundary ratio for geoseries
-        r_ib: Inner boundary ratio for geoseries
-        y_refinement: Refinement location for geoseries [adimensional]
-        tangent_vec_1: Tangent vector at the first endpoint (required for 'spline' type)
-        tangent_vec_2: Tangent vector at the second endpoint (required for 'spline' type)
-        tension: Tension parameter for spline lines
-        bias: Bias parameter for spline lines
+    Attributes
+    ----------
+    type : str
+        Line type ('spline' or 'straight')
+    end_points : list[int]
+        List of two point IDs defining the line endpoints (1-based indices)
+    nelem_line : int
+        Number of elements along line
+    type_span : str
+        Spanwise discretization type: could be 'uniform', 'cosine', 'cosine_ib', 'cosine_ob', 'geoseries', 'geoseries_ob', 'geoseries_ib'
+    r_ob : float, optional
+        Outer boundary ratio for geoseries
+    r_ib : float, optional
+        Inner boundary ratio for geoseries
+    y_refinement : float, optional
+        Refinement location for geoseries [adimensional]
+    tangent_vec_1 : list[float], optional
+        Tangent vector at the first endpoint (required for 'spline' type)
+    tangent_vec_2 : list[float], optional
+        Tangent vector at the second endpoint (required for 'spline' type)
+    tension : float, optional
+        Tension parameter for spline lines
+    bias : float, optional
+        Bias parameter for spline lines
     """
 
     type: str
@@ -157,11 +179,17 @@ class Line:
 @dataclass
 class Section:
     """Section definition for parametric mesh.
-    Attributes:
-        chord: Section chord length
-        twist: Section twist angle (degrees)
-        airfoil: Airfoil section name (without .dat extension)
-        airfoil_table: Airfoil aerodynamic table name (without .c81 extension)
+
+    Attributes
+    ----------
+    chord : float
+        Section chord length
+    twist : float
+        Section twist angle (degrees)
+    airfoil : str
+        Airfoil section name (without .dat extension)
+    airfoil_table : str, optional
+        Airfoil aerodynamic table name (without .c81 extension)
     """
 
     chord: float
@@ -173,15 +201,25 @@ class Section:
 @dataclass
 class Region:
     """Region definition for parametric mesh.
-    Attributes:
-        span: Region span length
-        sweep: Sweep angle (degrees)
-        dihed: Dihedral angle (degrees)
-        nelem_span: Number of elements along span
-        type_span: Spanwise discretization type
-        r_ob: Outer boundary ratio for geoseries
-        r_ib: Inner boundary ratio for geoseries
-        y_refinement: Refinement location for geoseries
+
+    Attributes
+    ----------
+    span : float
+        Region span length
+    sweep : float
+        Sweep angle (degrees)
+    dihed : float
+        Dihedral angle (degrees)
+    nelem_span : int
+        Number of elements along span
+    type_span : str
+        Spanwise discretization type: could be 'uniform', 'cosine', 'cosine_ib', 'cosine_ob', 'geoseries', 'geoseries_ob', 'geoseries_ib'
+    r_ob : float, optional
+        Outer boundary ratio for geoseries
+    r_ib : float, optional
+        Inner boundary ratio for geoseries
+    y_refinement : float, optional
+        Refinement location for geoseries
     """
 
     span: float
@@ -221,30 +259,53 @@ class Region:
 @dataclass
 class MeshConfig:
     """Mesh configuration parameters.
-    Required attributes:
-        title: Mesh title/description
-        el_type: Element type ('l' for lifting-line, 'v' for vortex-lattice, 'p' for panel)
-        nelem_chord: Number of chordwise elements
-        type_chord: Chordwise discretization type can be: 'uniform', 'cosine', 'cosine_le', 'cosine_te', 'geoseries', 'geoseries_le', 'geoseries_te', 'geoseries_hi'
-        reference_chord_fraction: Reference chord fraction (default 0.25 [adimensional])
-        starting_point: Starting point for mesh generation [x, y, z] [dimensional]
-    Optional attributes:
-        airfoil_table_correction: Use airfoil table correction (for 'v' elements)
-        y_fountain: remove wake shedding for y<=y_fountain [dimensional]
-        mesh_symmetry: Enable symmetry plane
-        symmetry_point: Point on symmetry plane [x, y, z]
-        symmetry_normal: Normal vector to symmetry plane [nx, ny, nz]
-        mesh_mirror: Enable mirror plane
-        mirror_point: Point on mirror plane [x, y, z]
-        mirror_normal: Normal vector to mirror plane [nx, ny, nz]
-        r: Outer boundary ratio for geoseries_le or geoseries_te
-        r_ob: Outer boundary ratio for geoseries
-        r_ib: Inner boundary ratio for geoseries
-        r_le_fix: Leading edge fixed ratio for geoseries_hi
-        r_te_fix: Trailing edge fixed ratio for geoseries_hi
-        r_le_moving: Leading edge moving ratio for geoseries_hi
-        r_te_moving: Trailing edge moving ratio for geoseries_hi
-        x_refinement: Refinement location for geoseries [adimensional]
+
+    Attributes
+    ----------
+    title : str
+        Mesh title/description
+    el_type : str
+        Element type ('l' for lifting-line, 'v' for vortex-lattice, 'p' for panel)
+    nelem_chord : int
+        Number of chordwise elements
+    type_chord : str
+        Chordwise discretization type can be: 'uniform', 'cosine', 'cosine_le', 'cosine_te', 'geoseries', 'geoseries_le', 'geoseries_te', 'geoseries_hi'
+    reference_chord_fraction : float
+        Reference chord fraction (default 0.25 [adimensional])
+    starting_point : list[float]
+        Starting point for mesh generation [x, y, z] [dimensional]
+    airfoil_table_correction : bool, optional
+        Use airfoil table correction (for 'v' elements)
+    y_fountain : float, optional
+        Remove wake shedding for y<=y_fountain [dimensional]
+    mesh_symmetry : bool, optional
+        Enable symmetry plane
+    symmetry_point : list[float], optional
+        Point on symmetry plane [x, y, z]
+    symmetry_normal : list[float], optional
+        Normal vector to symmetry plane [nx, ny, nz]
+    mesh_mirror : bool, optional
+        Enable mirror plane
+    mirror_point : list[float], optional
+        Point on mirror plane [x, y, z]
+    mirror_normal : list[float], optional
+        Normal vector to mirror plane [nx, ny, nz]
+    r : float, optional
+        Outer boundary ratio for geoseries_le or geoseries_te
+    r_ob : float, optional
+        Outer boundary ratio for geoseries
+    r_ib : float, optional
+        Inner boundary ratio for geoseries
+    r_le_fix : float, optional
+        Leading edge fixed ratio for geoseries_hi
+    r_te_fix : float, optional
+        Trailing edge fixed ratio for geoseries_hi
+    r_le_moving : float, optional
+        Leading edge moving ratio for geoseries_hi
+    r_te_moving : float, optional
+        Trailing edge moving ratio for geoseries_hi
+    x_refinement : float, optional
+        Refinement location for geoseries [adimensional]
     """
 
     title: str
@@ -316,18 +377,26 @@ class MeshConfig:
 @dataclass
 class PointwiseMesh:
     """Container for pointwise mesh data with validation.
+
     This class groups related mesh data and validates it upon creation.
     It provides a convenient interface for creating and writing meshes.
-    Attributes:
-        config: Mesh configuration
-        points: List of mesh points
-        lines: List of connecting lines
-    Example:
-        >>> config = MeshConfig('Wing', 'v', 20, 'uniform', 0.25)
-        >>> points = [Point(0, 0, 0, 1.0, 0, 'naca0012')]
-        >>> lines = [Line('straight', 1, 2, 10, 'uniform')]
-        >>> mesh = PointwiseMesh(config, points, lines)
-        >>> mesh.write('wing.in')
+
+    Attributes
+    ----------
+    config : MeshConfig
+        Mesh configuration
+    points : list[Point]
+        List of mesh points
+    lines : list[Line]
+        List of connecting lines
+
+    Examples
+    --------
+    >>> config = MeshConfig('Wing', 'v', 20, 'uniform', 0.25)
+    >>> points = [Point(0, 0, 0, 1.0, 0, 'naca0012')]
+    >>> lines = [Line('straight', 1, 2, 10, 'uniform')]
+    >>> mesh = PointwiseMesh(config, points, lines)
+    >>> mesh.write('wing.in')
     """
 
     config: MeshConfig
@@ -397,17 +466,22 @@ class ParametricMesh:
     This class groups related mesh data and validates it upon creation.
     It provides a convenient interface for creating and writing meshes.
 
-    Attributes:
-        config: Mesh configuration
-        sections: List of wing sections (n+1 sections for n regions)
-        regions: List of regions connecting sections (n regions)
+    Attributes
+    ----------
+    config : MeshConfig
+        Mesh configuration
+    sections : list[Section]
+        List of wing sections (n+1 sections for n regions)
+    regions : list[Region]
+        List of regions connecting sections (n regions)
 
-    Example:
-        >>> config = MeshConfig('Wing', 'v', 20, 'uniform', 0.25)
-        >>> sections = [Section(1.0, 0, 'naca0012'), Section(0.8, 5, 'naca0012')]
-        >>> regions = [Region(5.0, 10.0, 0.0, 10, 'uniform')]
-        >>> mesh = ParametricMesh(config, sections, regions)
-        >>> mesh.write('wing.in')
+    Examples
+    --------
+    >>> config = MeshConfig('Wing', 'v', 20, 'uniform', 0.25)
+    >>> sections = [Section(1.0, 0, 'naca0012'), Section(0.8, 5, 'naca0012')]
+    >>> regions = [Region(5.0, 10.0, 0.0, 10, 'uniform')]
+    >>> mesh = ParametricMesh(config, sections, regions)
+    >>> mesh.write('wing.in')
     """
 
     config: MeshConfig
@@ -729,7 +803,7 @@ def _write_end_tangents(line: Line, points: list[Point], file: TextIO) -> None:
     # normalize tangents
     tangent_1 = tangent_1 / np.linalg.norm(tangent_1)
     tangent_2 = tangent_2 / np.linalg.norm(tangent_2)
-    
+
     # Store as lists (convert from numpy arrays)
     line.tangent_vec_1 = tangent_1.tolist()
     line.tangent_vec_2 = tangent_2.tolist()
@@ -835,12 +909,12 @@ def write_pointwise_mesh(
         ... )
         >>>
         >>> points = [
-        ...     Point(0.0, 0.0, 0.0, 1.0, 0.0, 'naca0012', 'naca0012'),
-        ...     Point(1.0, 0.0, 0.0, 1.0, 0.0, 'naca0012', 'naca0012')
+        ...     Point(1, [0.0, 0.0, 0.0], 1.0, 0.0, 'naca0012', 'naca0012'),
+        ...     Point(2, [1.0, 0.0, 0.0], 1.0, 0.0, 'naca0012', 'naca0012')
         ... ]
         >>>
         >>> lines = [
-        ...     Line('straight', 1, 2, 10, 'uniform')
+        ...     Line('straight', [1, 2], 10, 'uniform')
         ... ]
         >>>
         >>> write_pointwise_mesh('mesh.in', points, lines, config)
